setMethod("Truncate", "AbscontDistribution",
          function(object, lower = -Inf, upper = Inf){
            newgaps <- gaps(object)
            if(!is.null(newgaps)){
               newgaps[,1] <- pmax(newgaps[,1],lower)
               newgaps[,2] <- pmin(newgaps[,1],upper)
               newgaps <- newgaps[newgaps[,1]<newgaps[,2],]
               if(nrow(newgaps)==0) newgaps <- NULL}
            ## new random number function
            rnew <- function(n){
                 rn <- r(object)(n)
                 while(TRUE){
                   rn[rn < lower] = NA
                   rn[rn > upper] = NA
                   index = is.na(rn)
                   if(!(any(index))) break
                   rn[index] = r(object)(sum(index))
                 }
                 rn}

            ## new cdf
            plower <- p(object)(lower)
            pupper <- p(object)(upper)
            restmass <-  pupper-plower
            if(restmass < getdistrOption("TruncQuantile"))
               stop("too little mass between args 'lower' and 'upper'")

            pnew <- .makeP(substitute(e1, list(e1 = object)),
                           substitute(alist(q = pmax(pmin(q,upper),lower)),
                                      list(upper=upper, lower=lower)),
                           fac = 1/restmass,
                           fac2 = substitute(ifelse(lower.tail,fa1,fa2),
                                      list(fa1 = -plower/restmass,
                                           fa2 = 1 - (1-plower)/restmass)))

            ## new density

            dnew <- .makeD(substitute(e1, list(e1 = object)),
                           substitute(alist(x = x)),
                           stand = restmass,
                           fac = substitute((x<=upper & x > lower),
                                     list(lower=lower,upper=upper)))

            # new quantile
            qL1 <- max(getLow(object), lower)
            qU1 <- min(getUp(object), upper)
            n <- getdistrOption("DefaultNrGridPoints")
            h <- (qU1-qL1)/n
            xseq <- seq(from = qL1, to = qU1, by = h)
            px.l <- pnew(xseq, lower.tail = TRUE)
            px.u <- pnew(xseq, lower.tail = FALSE)
            qL2 <- max(q(object)(0),lower)
            qU2 <- min(q(object)(1),upper)

            qnew <- .makeQNew(xseq, px.l, px.u, FALSE, qL2, qU2)

            return(AbscontDistribution( r = rnew, gaps = newgaps,
                   d = dnew, p = pnew, q = qnew, .withArith = TRUE,
                   .withSim = object@.withSim))
          })

setMethod("Truncate", "DiscreteDistribution",
          function(object, lower = -Inf, upper = Inf){
            supp <- support(object)
            newsupport <- supp[supp<=upper & supp>lower]
            if(! length(newsupport))
               stop("too little mass between args 'lower' and 'upper'")
            pnewsupport <- d(object)(newsupport)/sum(d(object)(newsupport))
            DiscreteDistribution(supp = newsupport, prob = pnewsupport,
                     .withArith = TRUE)
          })

setMethod("Truncate", "UnivarLebDecDistribution",
          function(object, lower = -Inf, upper = Inf, 
                   withSimplify = getdistrOption("simplifyD")){
            aD <- acPart(object)
            aw <- acWeight(object)
            dD <- discretePart(object)
            dw <- 1 - aw
            arestmass <- p(aD)(upper) - p(aD)(lower)
            drestmass <- p(dD)(upper) - p(dD)(lower)
            awnew <- arestmass/(drestmass+arestmass)
            aDnew <- Truncate(aD, lower, upper)
            dDnew <- Truncate(dD, lower, upper)
            Dnew <- UnivarLebDecDistribution(acPart = aDnew,
                        discretePart = dDnew, acWeight = awnew)
            if(withSimplify) Dnew <- simplifyD(Dnew)
            Dnew})
